@@ -1,9 +1,9 @@
 #!/bin/sh
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: zip-archive
-version: 0.3.0.1
-id: zip-archive-0.3.0.1-2bfc79c766a6020efc6123272df9282f
-key: zipar_LIPTvqpMT3eIHUoBstaWZy
+version: 0.3.0.2
+id: zip-archive-0.3.0.2-15b8e9a70ed3ab3db3683741297aa226
+key: zipar_5cVNzr8QTs6IaB6wCygXAT
 license: BSD3
 maintainer: jgm@berkeley.edu
 homepage: http://github.com/jgm/zip-archive
@@ -17,10 +17,10 @@ exposed: True
 exposed-modules:
     Codec.Archive.Zip
 trusted: False
-import-dirs: /usr/lib/ghc-7.10.3/site-local/zip-archive-0.3.0.1
-library-dirs: /usr/lib/ghc-7.10.3/site-local/zip-archive-0.3.0.1
-data-dir: /usr/share/arm-linux-ghc-7.10.3/zip-archive-0.3.0.1
-hs-libraries: HSzip-archive-0.3.0.1-LIPTvqpMT3eIHUoBstaWZy
+import-dirs: /usr/lib/ghc-7.10.3/site-local/zip-archive-0.3.0.2
+library-dirs: /usr/lib/ghc-7.10.3/site-local/zip-archive-0.3.0.2
+data-dir: /usr/share/arm-linux-ghc-7.10.3/zip-archive-0.3.0.2
+hs-libraries: HSzip-archive-0.3.0.2-5cVNzr8QTs6IaB6wCygXAT
 depends:
     array-0.5.1.0-a4b4f31b03b7779670557ea46745a386
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
